@@ -1,11 +1,17 @@
 import io
 import codecs
 import chardet
+from os import PathLike
+from typing import cast, BinaryIO, Union, TYPE_CHECKING
+from normality.util import Encoding
 
-DEFAULT_ENCODING = 'utf-8'
+if TYPE_CHECKING:
+    from chardet import _IntermediateResultType
+
+DEFAULT_ENCODING = "utf-8"
 
 
-def _is_encoding_codec(encoding):
+def _is_encoding_codec(encoding: Encoding) -> bool:
     """Check if a given string is a valid encoding name."""
     try:
         codecs.lookup(encoding)
@@ -14,34 +20,39 @@ def _is_encoding_codec(encoding):
         return False
 
 
-def normalize_encoding(encoding, default=DEFAULT_ENCODING):
+def normalize_encoding(encoding: str, default: Encoding = DEFAULT_ENCODING) -> str:
     """Normalize the encoding name, replace ASCII w/ UTF-8."""
     if encoding is None:
         return default
     encoding = encoding.lower().strip()
-    if encoding in ['', 'ascii']:
+    if encoding in ["", "ascii"]:
         return default
     if _is_encoding_codec(encoding):
         return encoding
-    encoding = encoding.replace('-', '')
+    encoding = encoding.replace("-", "")
     if _is_encoding_codec(encoding):
         return encoding
     return default
 
 
-def normalize_result(result, default, threshold=0.2):
+def normalize_result(
+    result: "_IntermediateResultType", default: Encoding, threshold: float = 0.2
+) -> Encoding:
     """Interpret a chardet result."""
     if result is None:
         return default
-    if result.get('confidence') is None:
+    confidence = result.get("confidence")
+    if confidence is None:
         return default
-    if result.get('confidence') < threshold:
+    if float(confidence) < threshold:
         return default
-    return normalize_encoding(result.get('encoding'),
-                              default=default)
+    encoding = result.get("encoding")
+    if encoding is None:
+        return default
+    return normalize_encoding(encoding, default=default)
 
 
-def guess_encoding(text, default=DEFAULT_ENCODING):
+def guess_encoding(text: bytes, default: Encoding = DEFAULT_ENCODING) -> Encoding:
     """Guess string encoding.
 
     Given a piece of text, apply character encoding detection to
@@ -51,7 +62,7 @@ def guess_encoding(text, default=DEFAULT_ENCODING):
     return normalize_result(result, default=default)
 
 
-def guess_file_encoding(fh, default=DEFAULT_ENCODING):
+def guess_file_encoding(fh: BinaryIO, default: Encoding = DEFAULT_ENCODING) -> Encoding:
     """Guess encoding from a file handle."""
     start = fh.tell()
     detector = chardet.UniversalDetector()
@@ -68,7 +79,11 @@ def guess_file_encoding(fh, default=DEFAULT_ENCODING):
     return normalize_result(detector.result, default=default)
 
 
-def guess_path_encoding(file_path, default=DEFAULT_ENCODING):
+def guess_path_encoding(
+    file_path: Union[PathLike[str], PathLike[bytes], str, bytes],
+    default: Encoding = DEFAULT_ENCODING,
+) -> Encoding:
     """Wrapper to open that damn file for you, lazy bastard."""
-    with io.open(file_path, 'rb') as fh:
-        return guess_file_encoding(fh, default=default)
+    with io.open(file_path, "rb") as fh:
+        fhb = cast(BinaryIO, fh)
+        return guess_file_encoding(fhb, default=default)
